@@ -1,5 +1,26 @@
 import numpy as np
-from ndn4sid.constants import *
+from .constants import *
+
+import itertools
+
+
+
+def check_commuting_set(list_of_array):
+    '''
+    Function to check if all matrices in the argument list pairwise commute.
+    Parameters:
+        list_of_array: A list of arrays to be checked
+    Returns:
+        do_all_commute(boolean): True iff all matrices pairwise commute.
+    '''
+    do_all_commute = True
+    for pair in itertools.combinations(list_of_array,2):
+        commutator = lie(pair[0],pair[1])
+        if not(check_norm_is_zero(commutator)):
+            do_all_commute = False
+            return do_all_commute
+    return do_all_commute
+
 
 def get_random_matrix_with_rank_r(n,r=0):
     """
