@@ -6,6 +6,7 @@ import itertools
 from dataclasses import dataclass
 from .constants import *
 from .linearalgebra import *
+from .misc import *
 
 @dataclass()
 class SS:
@@ -214,4 +215,36 @@ def get_kalman_decomposition(SS):
 
     T_inv_est = np.concatenate((not_obs_con, obs_con, not_obs_not_con, obs_not_con), axis=1)
     T_est = np.linalg.inv(T_inv_est)
-    return T_inv_est, T_est
\ No newline at end of file
+    return T_inv_est, T_est
+
+
+def get_hankel_tensor(y,order):
+    """
+    A method to calculate the Hankel tensor of a nD array.
+    The Hankel tensor is constructed as
+    H[i,k_1,l_1,k_2,l_2,\dots, k_n,l_n] = y[i,k_1+l_1,k_2+l_2,\dots,k_n+l_n]
+    Parameters:
+        y(np.array): 1 + n dimensional dataset. The first dimension is for multiple outputs.
+        order(list(int)): Order of the Hankelization. The length is equal to n.
+    Returns:
+        H(np.array): A recursive Hankel tensor.
+    """
+    # The first dimension is reserved for multivariate signals. 
+    n_dim = np.ndim(y) - 1
+    size_y = y.shape[1:]
+    nb_output = y.shape[0]
+    
+    # Check if the dimension of the dataset is the same as the size of the order.
+    assert len(order) == n_dim
+    # Calculate the shape of the Hankel tensor.
+    H_shape = [sub for k,l in zip(size_y,order) for sub in (k-l+1,l)]
+    # Check if the size is positive
+    assert all([h>0 for h in H_shape])
+    
+    # Initialize the Hankel tensor, the first dimension is add and is equal to the number of outputs.
+    H = np.empty([nb_output] + H_shape)
+    # Create the index range, which is a list of ranges. 
+    for tenson_index in shape_to_iterator(H_shape):
+        data_index = tensor_index_to_data_index(tenson_index)
+        H[(slice(0,nb_output),*tenson_index)] = y[(slice(0,nb_output),*data_index)]
+    return H
\ No newline at end of file
